==> deepin-launchpad-debug-2.0.22-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-launchpad/dde-launchpad/qml/windowed/.qt/rcc/qrc_qmake_org_deepin_launchpad_windowed.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0xa,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x6f,0x72,0x67,0x2e,0x64,0x65,0x65,0x70,0x69,0x6e,
  0x2e,0x6c,0x61,0x75,0x6e,0x63,0x68,0x70,0x61,0x64,0x2e,0x77,0x69,0x6e,0x64,0x6f,
  0x77,0x65,0x64,0xa,0x6c,0x69,0x6e,0x6b,0x74,0x61,0x72,0x67,0x65,0x74,0x20,0x6c,
  0x61,0x75,0x6e,0x63,0x68,0x65,0x72,0x2d,0x71,0x6d,0x6c,0x2d,0x77,0x69,0x6e,0x64,
  0x6f,0x77,0x65,0x64,0xa,0x6f,0x70,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x20,0x70,0x6c,
  0x75,0x67,0x69,0x6e,0x20,0x6c,0x61,0x75,0x6e,0x63,0x68,0x65,0x72,0x2d,0x71,0x6d,
  0x6c,0x2d,0x77,0x69,0x6e,0x64,0x6f,0x77,0x65,0x64,0xa,0x63,0x6c,0x61,0x73,0x73,
  0x6e,0x61,0x6d,0x65,0x20,0x6f,0x72,0x67,0x5f,0x64,0x65,0x65,0x70,0x69,0x6e,0x5f,
  0x6c,0x61,0x75,0x6e,0x63,0x68,0x70,0x61,0x64,0x5f,0x77,0x69,0x6e,0x64,0x6f,0x77,
  0x65,0x64,0x50,0x6c,0x75,0x67,0x69,0x6e,0xa,0x74,0x79,0x70,0x65,0x69,0x6e,0x66,
  0x6f,0x20,0x6c,0x61,0x75,0x6e,0x63,0x68,0x65,0x72,0x2d,0x71,0x6d,0x6c,0x2d,0x77,
  0x69,0x6e,0x64,0x6f,0x77,0x65,0x64,0x2e,0x71,0x6d,0x6c,0x74,0x79,0x70,0x65,0x73,
  0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,0x71,0x74,0x2f,0x71,0x6d,0x6c,
  0x2f,0x6f,0x72,0x67,0x2f,0x64,0x65,0x65,0x70,0x69,0x6e,0x2f,0x6c,0x61,0x75,0x6e,
  0x63,0x68,0x70,0x61,0x64,0x2f,0x77,0x69,0x6e,0x64,0x6f,0x77,0x65,0x64,0x2f,0xa,
  0x57,0x69,0x6e,0x64,0x6f,0x77,0x65,0x64,0x46,0x72,0x61,0x6d,0x65,0x20,0x31,0x2e,
  0x30,0x20,0x57,0x69,0x6e,0x64,0x6f,0x77,0x65,0x64,0x46,0x72,0x61,0x6d,0x65,0x2e,
  0x71,0x6d,0x6c,0xa,0x53,0x69,0x64,0x65,0x42,0x61,0x72,0x20,0x31,0x2e,0x30,0x20,
  0x53,0x69,0x64,0x65,0x42,0x61,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x42,0x6f,0x74,0x74,
  0x6f,0x6d,0x42,0x61,0x72,0x20,0x31,0x2e,0x30,0x20,0x42,0x6f,0x74,0x74,0x6f,0x6d,
  0x42,0x61,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x41,0x6c,0x70,0x68,0x61,0x62,0x65,0x74,
  0x43,0x61,0x74,0x65,0x67,0x6f,0x72,0x79,0x50,0x6f,0x70,0x75,0x70,0x20,0x31,0x2e,
  0x30,0x20,0x41,0x6c,0x70,0x68,0x61,0x62,0x65,0x74,0x43,0x61,0x74,0x65,0x67,0x6f,
  0x72,0x79,0x50,0x6f,0x70,0x75,0x70,0x2e,0x71,0x6d,0x6c,0xa,0x41,0x70,0x70,0x4c,
  0x69,0x73,0x74,0x20,0x31,0x2e,0x30,0x20,0x41,0x70,0x70,0x4c,0x69,0x73,0x74,0x2e,
  0x71,0x6d,0x6c,0xa,0x41,0x70,0x70,0x4c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x20,
  0x31,0x2e,0x30,0x20,0x41,0x70,0x70,0x4c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x2e,
  0x71,0x6d,0x6c,0xa,0x49,0x63,0x6f,0x6e,0x49,0x74,0x65,0x6d,0x44,0x65,0x6c,0x65,
  0x67,0x61,0x74,0x65,0x20,0x31,0x2e,0x30,0x20,0x49,0x63,0x6f,0x6e,0x49,0x74,0x65,
  0x6d,0x44,0x65,0x6c,0x65,0x67,0x61,0x74,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x72,
  0x65,0x65,0x53,0x6f,0x72,0x74,0x4c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x20,0x31,
  0x2e,0x30,0x20,0x46,0x72,0x65,0x65,0x53,0x6f,0x72,0x74,0x4c,0x69,0x73,0x74,0x56,
  0x69,0x65,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x72,0x69,0x64,0x56,0x69,0x65,0x77,
  0x43,0x6f,0x6e,0x74,0x61,0x69,0x6e,0x65,0x72,0x20,0x31,0x2e,0x30,0x20,0x47,0x72,
  0x69,0x64,0x56,0x69,0x65,0x77,0x43,0x6f,0x6e,0x74,0x61,0x69,0x6e,0x65,0x72,0x2e,
  0x71,0x6d,0x6c,0xa,0x41,0x6e,0x61,0x6c,0x79,0x73,0x69,0x73,0x56,0x69,0x65,0x77,
  0x20,0x31,0x2e,0x30,0x20,0x41,0x6e,0x61,0x6c,0x79,0x73,0x69,0x73,0x56,0x69,0x65,
  0x77,0x2e,0x71,0x6d,0x6c,0xa,0x52,0x65,0x63,0x65,0x6e,0x74,0x6c,0x79,0x49,0x6e,
  0x73,0x74,0x61,0x6c,0x6c,0x65,0x64,0x56,0x69,0x65,0x77,0x20,0x31,0x2e,0x30,0x20,
  0x52,0x65,0x63,0x65,0x6e,0x74,0x6c,0x79,0x49,0x6e,0x73,0x74,0x61,0x6c,0x6c,0x65,
  0x64,0x56,0x69,0x65,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x72,0x65,0x71,0x75,0x65,
  0x6e,0x74,0x6c,0x79,0x55,0x73,0x65,0x64,0x56,0x69,0x65,0x77,0x20,0x31,0x2e,0x30,
  0x20,0x46,0x72,0x65,0x71,0x75,0x65,0x6e,0x74,0x6c,0x79,0x55,0x73,0x65,0x64,0x56,
  0x69,0x65,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x53,0x65,0x61,0x72,0x63,0x68,0x52,0x65,
  0x73,0x75,0x6c,0x74,0x56,0x69,0x65,0x77,0x20,0x31,0x2e,0x30,0x20,0x53,0x65,0x61,
  0x72,0x63,0x68,0x52,0x65,0x73,0x75,0x6c,0x74,0x56,0x69,0x65,0x77,0x2e,0x71,0x6d,
  0x6c,0xa,0x49,0x74,0x65,0x6d,0x42,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,
  0x20,0x31,0x2e,0x30,0x20,0x49,0x74,0x65,0x6d,0x42,0x61,0x63,0x6b,0x67,0x72,0x6f,
  0x75,0x6e,0x64,0x2e,0x71,0x6d,0x6c,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // launchpad
  0x0,0x9,
  0xc,0x49,0x13,0x74,
  0x0,0x6c,
  0x0,0x61,0x0,0x75,0x0,0x6e,0x0,0x63,0x0,0x68,0x0,0x70,0x0,0x61,0x0,0x64,
    // windowed
  0x0,0x8,
  0x0,0x4b,0x62,0x74,
  0x0,0x77,
  0x0,0x69,0x0,0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,0x65,0x0,0x64,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9b,0xd7,0xb4,0x34,0x70,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9b,0xd7,0xb4,0x34,0x70,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9b,0xd7,0xb4,0x34,0x70,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9b,0xd7,0xb4,0x34,0x70,
  // :/qt/qml/org/deepin
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9b,0xd7,0xb4,0x34,0x70,
  // :/qt/qml/org/deepin/launchpad
  0x0,0x0,0x0,0x34,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9b,0xd7,0xb4,0x34,0x70,
  // :/qt/qml/org/deepin/launchpad/windowed
  0x0,0x0,0x0,0x4c,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x9b,0xd7,0xb4,0x34,0x70,
  // :/qt/qml/org/deepin/launchpad/windowed/qmldir
  0x0,0x0,0x0,0x62,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xd7,0xb4,0x34,0x70,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_launchpad_windowed)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_launchpad_windowed)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_launchpad_windowed)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_launchpad_windowed)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_launchpad_windowed)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_launchpad_windowed)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> deepin-launchpad-debug-2.0.22-2-x86_64.pkg.tar.zst: usr/src/debug/deepin-launchpad/dde-launchpad/qml/windowed/.qt/rcc/qrc_qmake_org_deepin_launchpad_windowed.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0xa,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x6f,0x72,0x67,0x2e,0x64,0x65,0x65,0x70,0x69,0x6e,
  0x2e,0x6c,0x61,0x75,0x6e,0x63,0x68,0x70,0x61,0x64,0x2e,0x77,0x69,0x6e,0x64,0x6f,
  0x77,0x65,0x64,0xa,0x6c,0x69,0x6e,0x6b,0x74,0x61,0x72,0x67,0x65,0x74,0x20,0x6c,
  0x61,0x75,0x6e,0x63,0x68,0x65,0x72,0x2d,0x71,0x6d,0x6c,0x2d,0x77,0x69,0x6e,0x64,
  0x6f,0x77,0x65,0x64,0xa,0x6f,0x70,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x20,0x70,0x6c,
  0x75,0x67,0x69,0x6e,0x20,0x6c,0x61,0x75,0x6e,0x63,0x68,0x65,0x72,0x2d,0x71,0x6d,
  0x6c,0x2d,0x77,0x69,0x6e,0x64,0x6f,0x77,0x65,0x64,0xa,0x63,0x6c,0x61,0x73,0x73,
  0x6e,0x61,0x6d,0x65,0x20,0x6f,0x72,0x67,0x5f,0x64,0x65,0x65,0x70,0x69,0x6e,0x5f,
  0x6c,0x61,0x75,0x6e,0x63,0x68,0x70,0x61,0x64,0x5f,0x77,0x69,0x6e,0x64,0x6f,0x77,
  0x65,0x64,0x50,0x6c,0x75,0x67,0x69,0x6e,0xa,0x74,0x79,0x70,0x65,0x69,0x6e,0x66,
  0x6f,0x20,0x6c,0x61,0x75,0x6e,0x63,0x68,0x65,0x72,0x2d,0x71,0x6d,0x6c,0x2d,0x77,
  0x69,0x6e,0x64,0x6f,0x77,0x65,0x64,0x2e,0x71,0x6d,0x6c,0x74,0x79,0x70,0x65,0x73,
  0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,0x71,0x74,0x2f,0x71,0x6d,0x6c,
  0x2f,0x6f,0x72,0x67,0x2f,0x64,0x65,0x65,0x70,0x69,0x6e,0x2f,0x6c,0x61,0x75,0x6e,
  0x63,0x68,0x70,0x61,0x64,0x2f,0x77,0x69,0x6e,0x64,0x6f,0x77,0x65,0x64,0x2f,0xa,
  0x57,0x69,0x6e,0x64,0x6f,0x77,0x65,0x64,0x46,0x72,0x61,0x6d,0x65,0x20,0x31,0x2e,
  0x30,0x20,0x57,0x69,0x6e,0x64,0x6f,0x77,0x65,0x64,0x46,0x72,0x61,0x6d,0x65,0x2e,
  0x71,0x6d,0x6c,0xa,0x53,0x69,0x64,0x65,0x42,0x61,0x72,0x20,0x31,0x2e,0x30,0x20,
  0x53,0x69,0x64,0x65,0x42,0x61,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x42,0x6f,0x74,0x74,
  0x6f,0x6d,0x42,0x61,0x72,0x20,0x31,0x2e,0x30,0x20,0x42,0x6f,0x74,0x74,0x6f,0x6d,
  0x42,0x61,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x41,0x6c,0x70,0x68,0x61,0x62,0x65,0x74,
  0x43,0x61,0x74,0x65,0x67,0x6f,0x72,0x79,0x50,0x6f,0x70,0x75,0x70,0x20,0x31,0x2e,
  0x30,0x20,0x41,0x6c,0x70,0x68,0x61,0x62,0x65,0x74,0x43,0x61,0x74,0x65,0x67,0x6f,
  0x72,0x79,0x50,0x6f,0x70,0x75,0x70,0x2e,0x71,0x6d,0x6c,0xa,0x41,0x70,0x70,0x4c,
  0x69,0x73,0x74,0x20,0x31,0x2e,0x30,0x20,0x41,0x70,0x70,0x4c,0x69,0x73,0x74,0x2e,
  0x71,0x6d,0x6c,0xa,0x41,0x70,0x70,0x4c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x20,
  0x31,0x2e,0x30,0x20,0x41,0x70,0x70,0x4c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x2e,
  0x71,0x6d,0x6c,0xa,0x49,0x63,0x6f,0x6e,0x49,0x74,0x65,0x6d,0x44,0x65,0x6c,0x65,
  0x67,0x61,0x74,0x65,0x20,0x31,0x2e,0x30,0x20,0x49,0x63,0x6f,0x6e,0x49,0x74,0x65,
  0x6d,0x44,0x65,0x6c,0x65,0x67,0x61,0x74,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x72,
  0x65,0x65,0x53,0x6f,0x72,0x74,0x4c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x20,0x31,
  0x2e,0x30,0x20,0x46,0x72,0x65,0x65,0x53,0x6f,0x72,0x74,0x4c,0x69,0x73,0x74,0x56,
  0x69,0x65,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x72,0x69,0x64,0x56,0x69,0x65,0x77,
  0x43,0x6f,0x6e,0x74,0x61,0x69,0x6e,0x65,0x72,0x20,0x31,0x2e,0x30,0x20,0x47,0x72,
  0x69,0x64,0x56,0x69,0x65,0x77,0x43,0x6f,0x6e,0x74,0x61,0x69,0x6e,0x65,0x72,0x2e,
  0x71,0x6d,0x6c,0xa,0x41,0x6e,0x61,0x6c,0x79,0x73,0x69,0x73,0x56,0x69,0x65,0x77,
  0x20,0x31,0x2e,0x30,0x20,0x41,0x6e,0x61,0x6c,0x79,0x73,0x69,0x73,0x56,0x69,0x65,
  0x77,0x2e,0x71,0x6d,0x6c,0xa,0x52,0x65,0x63,0x65,0x6e,0x74,0x6c,0x79,0x49,0x6e,
  0x73,0x74,0x61,0x6c,0x6c,0x65,0x64,0x56,0x69,0x65,0x77,0x20,0x31,0x2e,0x30,0x20,
  0x52,0x65,0x63,0x65,0x6e,0x74,0x6c,0x79,0x49,0x6e,0x73,0x74,0x61,0x6c,0x6c,0x65,
  0x64,0x56,0x69,0x65,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x72,0x65,0x71,0x75,0x65,
  0x6e,0x74,0x6c,0x79,0x55,0x73,0x65,0x64,0x56,0x69,0x65,0x77,0x20,0x31,0x2e,0x30,
  0x20,0x46,0x72,0x65,0x71,0x75,0x65,0x6e,0x74,0x6c,0x79,0x55,0x73,0x65,0x64,0x56,
  0x69,0x65,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x53,0x65,0x61,0x72,0x63,0x68,0x52,0x65,
  0x73,0x75,0x6c,0x74,0x56,0x69,0x65,0x77,0x20,0x31,0x2e,0x30,0x20,0x53,0x65,0x61,
  0x72,0x63,0x68,0x52,0x65,0x73,0x75,0x6c,0x74,0x56,0x69,0x65,0x77,0x2e,0x71,0x6d,
  0x6c,0xa,0x49,0x74,0x65,0x6d,0x42,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,
  0x20,0x31,0x2e,0x30,0x20,0x49,0x74,0x65,0x6d,0x42,0x61,0x63,0x6b,0x67,0x72,0x6f,
  0x75,0x6e,0x64,0x2e,0x71,0x6d,0x6c,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // launchpad
  0x0,0x9,
  0xc,0x49,0x13,0x74,
  0x0,0x6c,
  0x0,0x61,0x0,0x75,0x0,0x6e,0x0,0x63,0x0,0x68,0x0,0x70,0x0,0x61,0x0,0x64,
    // windowed
  0x0,0x8,
  0x0,0x4b,0x62,0x74,
  0x0,0x77,
  0x0,0x69,0x0,0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,0x65,0x0,0x64,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9c,0x9,0x50,0x8,0xb0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9c,0x9,0x50,0x8,0xb0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9c,0x9,0x50,0x8,0xb0,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9c,0x9,0x50,0x8,0xb0,
  // :/qt/qml/org/deepin
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9c,0x9,0x50,0x8,0xb0,
  // :/qt/qml/org/deepin/launchpad
  0x0,0x0,0x0,0x34,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9c,0x9,0x50,0x8,0xb0,
  // :/qt/qml/org/deepin/launchpad/windowed
  0x0,0x0,0x0,0x4c,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x9c,0x9,0x50,0x8,0xb0,
  // :/qt/qml/org/deepin/launchpad/windowed/qmldir
  0x0,0x0,0x0,0x62,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9c,0x9,0x50,0x8,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_launchpad_windowed)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_launchpad_windowed)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_launchpad_windowed)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_launchpad_windowed)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_launchpad_windowed)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_launchpad_windowed)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
